==> uci_dataset-0.0.5.tar.gz: uci_dataset-0.0.5/README.md <==
[![Python][python-shield]][python-url]
[![Documentation][documentation-shield]][documentation-url]
[![Github][github-shield]][github-url]
[![MIT License][license-shield]][license-url]
[![LinkedIn][linkedin-shield]][linkedin-url]



<!-- PROJECT LOGO -->
<br />
<p align="center">
  <h3 align="center">UCI Dataset</h3>

  <p align="center">
    A tool for loading UCI Machine Learning Repository datasets easily without need to download them.
    <br />
    <a href="https://github.com/maryami66/uci_dataset/blob/main/List_of_Data.md"><strong>List of avaiable dataset»</strong></a>
    <br />
    <br />
  </p>


<!-- ABOUT THE PROJECT -->
## List of dataset
[Here](https://github.com/maryami66/uci_dataset/blob/main/List_of_Data.md) you can find the list of dataset in the latest release
along with the name of the function to load the data.



### Prerequisites
The requirements are `numpy`, `pandas`, and `scipy`

### Installation

1. Clone the repo
   ```sh
   git clone https://github.com/maryami66/uci_dataset
   ```
2. Install NPM packages
   ```sh
   pip install uci-dataset
   ```

<!-- USAGE EXAMPLES -->
## Usage
Load the data using `load_dataname`

```
import uci_dataset as dataset

abolone = dataset.load_abolone()

```


<!-- CONTRIBUTING -->
## Contributing

I would be happy if a contributor add more dataset.

1. Fork the Project
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request



<!-- LICENSE -->
## License

Distributed under the MIT License. See `LICENSE` for more information.



<!-- CONTACT -->
## Contact

Maryam Bahrami - maryami_66@yahoo.com

Project Link: [https://github.com/maryami66/uci-dataset](https://github.com/maryami66/uci-dataset)



<!-- ACKNOWLEDGEMENTS -->
## Acknowledgements
* [Best-README-Template](https://github.com/othneildrew/Best-README-Template)


<!-- MARKDOWN LINKS & IMAGES -->
<!-- https://www.markdownguide.org/basic-syntax/#reference-style-links -->
[python-shield]: https://img.shields.io/badge/Python-v3.7-blue
[python-url]: https://www.python.org/downloads/release/python-370/
[documentation-shield]: https://img.shields.io/badge/docs-passing-brightgreen
[documentation-url]: https://github.com/maryami66/uci-dataset/doc/build/html/index.html
[github-shield]: https://img.shields.io/badge/status-stable-brightgreen
[github-url]: https://github.com/maryami66/uci-dataset
[license-shield]: https://img.shields.io/github/license/othneildrew/Best-README-Template.svg?style=for-the-badge
[license-url]: https://github.com/maryami66/uci-dataset/blob/master/LICENSE.txt
[linkedin-shield]: https://img.shields.io/badge/-LinkedIn-black.svg?style=for-the-badge&logo=linkedin&colorB=555
[linkedin-url]: https://www.linkedin.com/in/maryam-bahrami-a6558496/
[product-screenshot]: images/screenshot.png

==> uci_dataset-0.0.6.tar.gz: uci_dataset-0.0.6/README.md <==
[![Python][python-shield]][python-url]
[![Documentation][documentation-shield]][documentation-url]
[![Github][github-shield]][github-url]
[![MIT License][license-shield]][license-url]
[![LinkedIn][linkedin-shield]][linkedin-url]



<!-- PROJECT LOGO -->
<br />
<p align="center">
  <h3 align="center">UCI Dataset</h3>

  <p align="center">
    A tool for loading UCI Machine Learning Repository datasets easily without need to download them.
    <br />
    <a href="https://github.com/maryami66/uci_dataset/blob/main/List_of_Data.md"><strong>List of avaiable dataset»</strong></a>
    <br />
    <br />
  </p>


<!-- ABOUT THE PROJECT -->
## List of dataset
[Here](https://github.com/maryami66/uci_dataset/blob/main/lists/list_of_data.md) you can find the list of dataset in the latest release
along with the name of the function to load the data.



### Prerequisites
The requirements are `numpy`, `pandas`, and `scipy`

### Installation

1. Clone the repo
   ```sh
   git clone https://github.com/maryami66/uci_dataset
   ```
2. Install NPM packages
   ```sh
   pip install uci-dataset
   ```

<!-- USAGE EXAMPLES -->
## Usage
Load the data using `load_dataname`

```
import uci_dataset as dataset

abolone = dataset.load_abolone()

```


<!-- CONTRIBUTING -->
## Contributing

I would be happy if a contributor add more dataset.

1. Fork the Project
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request



<!-- LICENSE -->
## License

Distributed under the MIT License. See `LICENSE` for more information.



<!-- CONTACT -->
## Contact

Maryam Bahrami - maryami_66@yahoo.com

Project Link: [https://github.com/maryami66/uci-dataset](https://github.com/maryami66/uci-dataset)



<!-- ACKNOWLEDGEMENTS -->
## Acknowledgements
* [Best-README-Template](https://github.com/othneildrew/Best-README-Template)


<!-- MARKDOWN LINKS & IMAGES -->
<!-- https://www.markdownguide.org/basic-syntax/#reference-style-links -->
[python-shield]: https://img.shields.io/badge/Python-v3.7-blue
[python-url]: https://www.python.org/downloads/release/python-370/
[documentation-shield]: https://img.shields.io/badge/docs-passing-brightgreen
[documentation-url]: https://github.com/maryami66/uci-dataset/doc/build/html/index.html
[github-shield]: https://img.shields.io/badge/status-stable-brightgreen
[github-url]: https://github.com/maryami66/uci-dataset
[license-shield]: https://img.shields.io/github/license/othneildrew/Best-README-Template.svg?style=for-the-badge
[license-url]: https://github.com/maryami66/uci-dataset/blob/master/LICENSE.txt
[linkedin-shield]: https://img.shields.io/badge/-LinkedIn-black.svg?style=for-the-badge&logo=linkedin&colorB=555
[linkedin-url]: https://www.linkedin.com/in/maryam-bahrami-a6558496/
[product-screenshot]: images/screenshot.png
